The example consists in:
  - a script accepting a plugin for computing genome statistics over a range of sequence files
  - plugins for computing those statistics written in Python, Nim, Rust and as a shell script
